@@ -1,28 +1,28 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /* This file is part of the GtkHTML library.
-
-   Copyright 1999, 2000 Helix Code, Inc.
-
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+ *
+ * Copyright 1999, 2000 Helix Code, Inc.
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Library General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) any later version.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Library General Public License for more details.
+ *
+ * You should have received a copy of the GNU Library General Public License
+ * along with this library; see the file COPYING.LIB.  If not, write to
+ * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 /* This file is a bit of a hack.  To make things work in a really nice way, we
-   should have some extra methods in the various subclasses to implement cursor
-   movement.  But for now, I think this is a reasonable way to get things to
-   work.  */
+ * should have some extra methods in the various subclasses to implement cursor
+ * movement.  But for now, I think this is a reasonable way to get things to
+ * work.  */
 
 #include <config.h>
 #include <stdlib.h>
@@ -78,7 +78,7 @@ debug_location (const HTMLCursor *cursor)
 
 static void
 normalize (HTMLObject **object,
-	   guint *offset)
+           guint *offset)
 {
 	if (*offset == 0 && (*object)->prev != NULL) {
 		*object = html_object_prev_not_slave (*object);
@@ -89,7 +89,9 @@ normalize (HTMLObject **object,
 
 
 inline void
-html_cursor_init (HTMLCursor *cursor, HTMLObject *o, guint offset)
+html_cursor_init (HTMLCursor *cursor,
+                  HTMLObject *o,
+                  guint offset)
 {
 	cursor->object = o;
 	cursor->offset = offset;
@@ -130,7 +132,7 @@ html_cursor_destroy (HTMLCursor *cursor)
  **/
 void
 html_cursor_copy (HTMLCursor *dest,
-		  const HTMLCursor *src)
+                  const HTMLCursor *src)
 {
 	g_return_if_fail (dest != NULL);
 	g_return_if_fail (src != NULL);
@@ -163,7 +165,7 @@ html_cursor_normalize (HTMLCursor *cursor)
 
 void
 html_cursor_home (HTMLCursor *cursor,
-		  HTMLEngine *engine)
+                  HTMLEngine *engine)
 {
 	HTMLObject *obj;
 
@@ -205,8 +207,8 @@ html_cursor_home (HTMLCursor *cursor,
 
 static gboolean
 forward (HTMLCursor *cursor,
-	 HTMLEngine *engine,
-	 gboolean    exact_position)
+         HTMLEngine *engine,
+         gboolean exact_position)
 {
 	gboolean retval;
 	gboolean (*forward_func) (HTMLObject *self, HTMLCursor *cursor, HTMLEngine *engine);
@@ -225,7 +227,7 @@ forward (HTMLCursor *cursor,
 			if (!html_object_is_container (next))
 				cursor->offset = (next->parent == cursor->object->parent) ? 1 : 0;
 			cursor->object = next;
-			cursor->position ++;
+			cursor->position++;
 		} else
 			retval = FALSE;
 	}
@@ -234,8 +236,8 @@ forward (HTMLCursor *cursor,
 
 static gboolean
 html_cursor_real_forward (HTMLCursor *cursor,
-			  HTMLEngine *engine,
-			  gboolean    exact_position)
+                          HTMLEngine *engine,
+                          gboolean exact_position)
 {
 	gboolean retval;
 
@@ -257,22 +259,22 @@ html_cursor_real_forward (HTMLCursor *cursor,
 
 gboolean
 html_cursor_forward (HTMLCursor *cursor,
-		     HTMLEngine *engine)
+                     HTMLEngine *engine)
 {
 	return html_cursor_real_forward (cursor, engine, FALSE);
 }
 
 gboolean
 html_cursor_forward_one (HTMLCursor *cursor,
-			 HTMLEngine *engine)
+                         HTMLEngine *engine)
 {
 	return html_cursor_real_forward (cursor, engine, TRUE);
 }
 
 static gboolean
 backward (HTMLCursor *cursor,
-	  HTMLEngine *engine,
-	  gboolean    exact_position)
+          HTMLEngine *engine,
+          gboolean exact_position)
 {
 	gboolean retval;
 	gboolean (*backward_func) (HTMLObject *self, HTMLCursor *cursor, HTMLEngine *engine);
@@ -290,7 +292,7 @@ backward (HTMLCursor *cursor,
 			if (!html_object_is_container (prev))
 				cursor->offset = html_object_get_length (prev);
 			cursor->object = prev;
-			cursor->position --;
+			cursor->position--;
 		} else
 			retval = FALSE;
 	}
@@ -299,8 +301,8 @@ backward (HTMLCursor *cursor,
 
 static gboolean
 html_cursor_real_backward (HTMLCursor *cursor,
-			   HTMLEngine *engine,
-			   gboolean    exact_position)
+                           HTMLEngine *engine,
+                           gboolean exact_position)
 {
 	gboolean retval;
 
@@ -322,14 +324,14 @@ html_cursor_real_backward (HTMLCursor *cursor,
 
 gboolean
 html_cursor_backward (HTMLCursor *cursor,
-		      HTMLEngine *engine)
+                      HTMLEngine *engine)
 {
 	return html_cursor_real_backward (cursor, engine, FALSE);
 }
 
 gboolean
 html_cursor_backward_one (HTMLCursor *cursor,
-			  HTMLEngine *engine)
+                          HTMLEngine *engine)
 {
 	return html_cursor_real_backward (cursor, engine, TRUE);
 }
@@ -337,7 +339,7 @@ html_cursor_backward_one (HTMLCursor *cursor,
 
 gboolean
 html_cursor_up (HTMLCursor *cursor,
-		HTMLEngine *engine)
+                HTMLEngine *engine)
 {
 	HTMLCursor orig_cursor;
 	HTMLCursor prev_cursor;
@@ -369,7 +371,7 @@ html_cursor_up (HTMLCursor *cursor,
 				     engine->painter, cursor->offset,
 				     &x, &y);
 
-	if (! cursor->have_target_x) {
+	if (!cursor->have_target_x) {
 		cursor->target_x = x;
 		cursor->have_target_x = TRUE;
 	}
@@ -384,7 +386,7 @@ html_cursor_up (HTMLCursor *cursor,
 		prev_x = x;
 		prev_y = y;
 
-		if (! backward (cursor, engine, FALSE))
+		if (!backward (cursor, engine, FALSE))
 			return FALSE;
 
 		html_object_get_cursor_base (cursor->object,
@@ -411,13 +413,13 @@ html_cursor_up (HTMLCursor *cursor,
 
 		if (dir == HTML_DIRECTION_RTL) {
 			if (new_line && x >= target_x) {
-				if (! cursor->have_target_x) {
+				if (!cursor->have_target_x) {
 					cursor->have_target_x = TRUE;
 					cursor->target_x = target_x;
 				}
 
 				/* Choose the character which is the nearest to the
-				   target X.  */
+				 * target X.  */
 				if (prev_y == y && x - target_x >= target_x - prev_x) {
 					cursor->object = prev_cursor.object;
 					cursor->offset = prev_cursor.offset;
@@ -429,13 +431,13 @@ html_cursor_up (HTMLCursor *cursor,
 			}
 		} else {
 			if (new_line && x <= target_x) {
-				if (! cursor->have_target_x) {
+				if (!cursor->have_target_x) {
 					cursor->have_target_x = TRUE;
 					cursor->target_x = target_x;
 				}
 
 				/* Choose the character which is the nearest to the
-				   target X.  */
+				 * target X.  */
 				if (prev_y == y && target_x - x >= prev_x - target_x) {
 					cursor->object = prev_cursor.object;
 					cursor->offset = prev_cursor.offset;
@@ -452,7 +454,7 @@ html_cursor_up (HTMLCursor *cursor,
 
 gboolean
 html_cursor_down (HTMLCursor *cursor,
-		  HTMLEngine *engine)
+                  HTMLEngine *engine)
 {
 	HTMLCursor orig_cursor;
 	HTMLCursor prev_cursor;
@@ -484,7 +486,7 @@ html_cursor_down (HTMLCursor *cursor,
 				     engine->painter, cursor->offset,
 				     &x, &y);
 
-	if (! cursor->have_target_x) {
+	if (!cursor->have_target_x) {
 		cursor->target_x = x;
 		cursor->have_target_x = TRUE;
 	}
@@ -499,10 +501,10 @@ html_cursor_down (HTMLCursor *cursor,
 		prev_y = y;
 
 		if (dir == HTML_DIRECTION_RTL) {
-			if (! move_left (cursor, engine))
+			if (!move_left (cursor, engine))
 				return FALSE;
 		} else {
-			if (! move_right (cursor, engine))
+			if (!move_right (cursor, engine))
 				return FALSE;
 		}
 
@@ -530,13 +532,13 @@ html_cursor_down (HTMLCursor *cursor,
 
 		if (dir == HTML_DIRECTION_RTL) {
 			if (new_line && x <= target_x) {
-				if (! cursor->have_target_x) {
+				if (!cursor->have_target_x) {
 					cursor->have_target_x = TRUE;
 					cursor->target_x = target_x;
 				}
 
 				/* Choose the character which is the nearest to the
-				   target X.  */
+				 * target X.  */
 				if (prev_y == y && target_x - x >= prev_x - target_x) {
 					cursor->object = prev_cursor.object;
 					cursor->offset = prev_cursor.offset;
@@ -548,13 +550,13 @@ html_cursor_down (HTMLCursor *cursor,
 			}
 		} else {
 			if (new_line && x >= target_x) {
-				if (! cursor->have_target_x) {
+				if (!cursor->have_target_x) {
 					cursor->have_target_x = TRUE;
 					cursor->target_x = target_x;
 				}
 
 				/* Choose the character which is the nearest to the
-				   target X.  */
+				 * target X.  */
 				if (prev_y == y && x - target_x >= target_x - prev_x) {
 					cursor->object = prev_cursor.object;
 					cursor->offset = prev_cursor.offset;
@@ -571,10 +573,10 @@ html_cursor_down (HTMLCursor *cursor,
 
 static gboolean
 html_cursor_real_jump_to (HTMLCursor *cursor,
-			  HTMLEngine *engine,
-			  HTMLObject *object,
-			  guint       offset,
-			  gboolean    exact_position)
+                          HTMLEngine *engine,
+                          HTMLObject *object,
+                          guint offset,
+                          gboolean exact_position)
 {
 	HTMLCursor original;
 
@@ -623,9 +625,9 @@ html_cursor_real_jump_to (HTMLCursor *cursor,
  **/
 gboolean
 html_cursor_jump_to (HTMLCursor *cursor,
-		     HTMLEngine *engine,
-		     HTMLObject *object,
-		     guint       offset)
+                     HTMLEngine *engine,
+                     HTMLObject *object,
+                     guint offset)
 {
 	return html_cursor_real_jump_to (cursor, engine, object, offset, FALSE);
 }
@@ -642,9 +644,9 @@ html_cursor_jump_to (HTMLCursor *cursor,
  **/
 gboolean
 html_cursor_exactly_jump_to (HTMLCursor *cursor,
-			     HTMLEngine *engine,
-			     HTMLObject *object,
-			     guint       offset)
+                             HTMLEngine *engine,
+                             HTMLObject *object,
+                             guint offset)
 {
 	return html_cursor_real_jump_to (cursor, engine, object, offset, TRUE);
 }
@@ -654,7 +656,7 @@ html_cursor_exactly_jump_to (HTMLCursor *cursor,
 
 void
 html_cursor_beginning_of_document (HTMLCursor *cursor,
-				   HTMLEngine *engine)
+                                   HTMLEngine *engine)
 {
 	g_return_if_fail (cursor != NULL);
 	g_return_if_fail (engine != NULL);
@@ -671,7 +673,7 @@ html_cursor_beginning_of_document (HTMLCursor *cursor,
 
 void
 html_cursor_end_of_document (HTMLCursor *cursor,
-			     HTMLEngine *engine)
+                             HTMLEngine *engine)
 {
 	g_return_if_fail (cursor != NULL);
 	g_return_if_fail (engine != NULL);
@@ -696,9 +698,9 @@ html_cursor_get_position (HTMLCursor *cursor)
 
 static void
 html_cursor_real_jump_to_position (HTMLCursor *cursor,
-				   HTMLEngine *engine,
-				   gint        position,
-				   gboolean    exact_position)
+                                   HTMLEngine *engine,
+                                   gint position,
+                                   gboolean exact_position)
 {
 	g_return_if_fail (cursor != NULL);
 	g_return_if_fail (position >= 0);
@@ -708,12 +710,12 @@ html_cursor_real_jump_to_position (HTMLCursor *cursor,
 
 	if (cursor->position < position) {
 		while (cursor->position < position) {
-			if (! forward (cursor, engine, exact_position))
+			if (!forward (cursor, engine, exact_position))
 				break;
 		}
 	} else if (cursor->position > position) {
 		while (cursor->position > position) {
-			if (! backward (cursor, engine, exact_position))
+			if (!backward (cursor, engine, exact_position))
 				break;
 		}
 	}
@@ -722,25 +724,25 @@ html_cursor_real_jump_to_position (HTMLCursor *cursor,
 
 void
 html_cursor_jump_to_position (HTMLCursor *cursor,
-			      HTMLEngine *engine,
-			      gint        position)
+                              HTMLEngine *engine,
+                              gint position)
 {
 	html_cursor_real_jump_to_position (cursor, engine, position, FALSE);
 }
 
 void
 html_cursor_exactly_jump_to_position (HTMLCursor *cursor,
-				      HTMLEngine *engine,
-				      gint        position)
+                                      HTMLEngine *engine,
+                                      gint position)
 {
 	html_cursor_real_jump_to_position (cursor, engine, position, TRUE);
 }
 
 static void
 html_cursor_real_jump_to_position_no_spell (HTMLCursor *cursor,
-					    HTMLEngine *engine,
-					    gint        position,
-					    gboolean    exact_position)
+                                            HTMLEngine *engine,
+                                            gint position,
+                                            gboolean exact_position)
 {
 	gboolean need_spell_check;
 
@@ -752,16 +754,16 @@ html_cursor_real_jump_to_position_no_spell (HTMLCursor *cursor,
 
 void
 html_cursor_jump_to_position_no_spell (HTMLCursor *cursor,
-				       HTMLEngine *engine,
-				       gint        position)
+                                       HTMLEngine *engine,
+                                       gint position)
 {
 	html_cursor_real_jump_to_position_no_spell (cursor, engine, position, FALSE);
 }
 
 void
 html_cursor_exactly_jump_to_position_no_spell (HTMLCursor *cursor,
-					       HTMLEngine *engine,
-					       gint        position)
+                                               HTMLEngine *engine,
+                                               gint position)
 {
 	html_cursor_real_jump_to_position_no_spell (cursor, engine, position, TRUE);
 }
@@ -771,7 +773,7 @@ html_cursor_exactly_jump_to_position_no_spell (HTMLCursor *cursor,
 
 gboolean
 html_cursor_equal (const HTMLCursor *a,
-		   const HTMLCursor *b)
+                   const HTMLCursor *b)
 {
 	g_return_val_if_fail (a != NULL, FALSE);
 	g_return_val_if_fail (b != NULL, FALSE);
@@ -781,7 +783,7 @@ html_cursor_equal (const HTMLCursor *a,
 
 gboolean
 html_cursor_precedes (const HTMLCursor *a,
-		      const HTMLCursor *b)
+                      const HTMLCursor *b)
 {
 	g_return_val_if_fail (a != NULL, FALSE);
 	g_return_val_if_fail (b != NULL, FALSE);
@@ -791,7 +793,7 @@ html_cursor_precedes (const HTMLCursor *a,
 
 gboolean
 html_cursor_follows (const HTMLCursor *a,
-		     const HTMLCursor *b)
+                     const HTMLCursor *b)
 {
 	g_return_val_if_fail (a != NULL, FALSE);
 	g_return_val_if_fail (b != NULL, FALSE);
@@ -807,7 +809,7 @@ html_cursor_get_current_char (const HTMLCursor *cursor)
 
 	g_return_val_if_fail (cursor != NULL, 0);
 
-	if (! html_object_is_text (cursor->object)) {
+	if (!html_object_is_text (cursor->object)) {
 		if (cursor->offset < html_object_get_length (cursor->object))
 			return 0;
 
@@ -822,7 +824,7 @@ html_cursor_get_current_char (const HTMLCursor *cursor)
 		return html_text_get_char (HTML_TEXT (cursor->object), cursor->offset);
 
 	next = html_object_next_not_slave (cursor->object);
-	if (next == NULL || ! html_object_is_text (next))
+	if (next == NULL || !html_object_is_text (next))
 		return 0;
 
 	return html_text_get_char (HTML_TEXT (next), 0);
@@ -846,7 +848,8 @@ html_cursor_get_prev_char (const HTMLCursor *cursor)
 }
 
 gboolean
-html_cursor_beginning_of_paragraph (HTMLCursor *cursor, HTMLEngine *engine)
+html_cursor_beginning_of_paragraph (HTMLCursor *cursor,
+                                    HTMLEngine *engine)
 {
 	HTMLCursor copy;
 	HTMLObject *flow;
@@ -884,7 +887,8 @@ html_cursor_beginning_of_paragraph (HTMLCursor *cursor, HTMLEngine *engine)
 }
 
 gboolean
-html_cursor_end_of_paragraph (HTMLCursor *cursor, HTMLEngine *engine)
+html_cursor_end_of_paragraph (HTMLCursor *cursor,
+                              HTMLEngine *engine)
 {
 	HTMLCursor copy;
 	HTMLObject *flow;
@@ -922,12 +926,14 @@ html_cursor_end_of_paragraph (HTMLCursor *cursor, HTMLEngine *engine)
 }
 
 gboolean
-html_cursor_forward_n (HTMLCursor *cursor, HTMLEngine *e, guint n)
+html_cursor_forward_n (HTMLCursor *cursor,
+                       HTMLEngine *e,
+                       guint n)
 {
 	gboolean rv = FALSE;
 
 	while (n && html_cursor_forward (cursor, e)) {
-		n --;
+		n--;
 		rv = TRUE;
 	}
 
@@ -935,12 +941,14 @@ html_cursor_forward_n (HTMLCursor *cursor, HTMLEngine *e, guint n)
 }
 
 gboolean
-html_cursor_backward_n (HTMLCursor *cursor, HTMLEngine *e, guint n)
+html_cursor_backward_n (HTMLCursor *cursor,
+                        HTMLEngine *e,
+                        guint n)
 {
 	gboolean rv = FALSE;
 
 	while (n && html_cursor_backward (cursor, e)) {
-		n --;
+		n--;
 		rv = TRUE;
 	}
 
@@ -948,7 +956,8 @@ html_cursor_backward_n (HTMLCursor *cursor, HTMLEngine *e, guint n)
 }
 
 HTMLObject *
-html_cursor_child_of (HTMLCursor *cursor, HTMLObject *parent)
+html_cursor_child_of (HTMLCursor *cursor,
+                      HTMLObject *parent)
 {
 	HTMLObject *child = cursor->object;
 
@@ -962,14 +971,15 @@ html_cursor_child_of (HTMLCursor *cursor, HTMLObject *parent)
 }
 
 static gboolean
-move_to_next_object (HTMLCursor *cursor, HTMLEngine *e)
+move_to_next_object (HTMLCursor *cursor,
+                     HTMLEngine *e)
 {
 	HTMLObject *next;
 
 	next = html_object_next_cursor (cursor->object, (gint *) &cursor->offset);
 	if (next && next->parent) {
 		cursor->object = next;
-		cursor->position ++;
+		cursor->position++;
 
 		if (!html_object_is_container (next)) {
 			if (html_object_get_direction (next->parent) == HTML_DIRECTION_RTL) {
@@ -986,14 +996,15 @@ move_to_next_object (HTMLCursor *cursor, HTMLEngine *e)
 }
 
 static gboolean
-move_to_prev_object (HTMLCursor *cursor, HTMLEngine *e)
+move_to_prev_object (HTMLCursor *cursor,
+                     HTMLEngine *e)
 {
 	HTMLObject *prev;
 
 	prev = html_object_prev_cursor (cursor->object, (gint *) &cursor->offset);
 	if (prev && prev->parent) {
 		cursor->object = prev;
-		cursor->position --;
+		cursor->position--;
 
 		if (!html_object_is_container (prev)) {
 			if (html_object_get_direction (prev->parent) == HTML_DIRECTION_RTL) {
@@ -1010,7 +1021,8 @@ move_to_prev_object (HTMLCursor *cursor, HTMLEngine *e)
 }
 
 static gboolean
-move_left (HTMLCursor *cursor, HTMLEngine *e)
+move_left (HTMLCursor *cursor,
+           HTMLEngine *e)
 {
 	if (!html_object_cursor_left (cursor->object, e->painter, cursor)) {
 		if (cursor->object->parent) {
@@ -1025,7 +1037,8 @@ move_left (HTMLCursor *cursor, HTMLEngine *e)
 }
 
 gboolean
-html_cursor_left (HTMLCursor *cursor, HTMLEngine *engine)
+html_cursor_left (HTMLCursor *cursor,
+                  HTMLEngine *engine)
 {
 	gboolean retval;
 
@@ -1046,7 +1059,8 @@ html_cursor_left (HTMLCursor *cursor, HTMLEngine *engine)
 }
 
 static gboolean
-left_in_flow (HTMLCursor *cursor, HTMLEngine *e)
+left_in_flow (HTMLCursor *cursor,
+              HTMLEngine *e)
 {
 	gboolean retval;
 
@@ -1071,7 +1085,8 @@ left_in_flow (HTMLCursor *cursor, HTMLEngine *e)
 }
 
 static gboolean
-html_cursor_left_edge_of_line (HTMLCursor *cursor, HTMLEngine *engine)
+html_cursor_left_edge_of_line (HTMLCursor *cursor,
+                               HTMLEngine *engine)
 {
 	HTMLCursor prev_cursor;
 	gint x, y, prev_y;
@@ -1092,7 +1107,7 @@ html_cursor_left_edge_of_line (HTMLCursor *cursor, HTMLEngine *engine)
 				     &x, &prev_y);
 
 	while (1) {
-		if (! left_in_flow (cursor, engine))
+		if (!left_in_flow (cursor, engine))
 			return TRUE;
 
 		html_object_get_cursor_base (cursor->object, engine->painter, cursor->offset,
@@ -1109,7 +1124,8 @@ html_cursor_left_edge_of_line (HTMLCursor *cursor, HTMLEngine *engine)
 }
 
 static gboolean
-move_right (HTMLCursor *cursor, HTMLEngine *e)
+move_right (HTMLCursor *cursor,
+            HTMLEngine *e)
 {
 	gboolean retval;
 
@@ -1126,9 +1142,9 @@ move_right (HTMLCursor *cursor, HTMLEngine *e)
 
 		if (rv && !html_object_is_container (cursor->object) && cursor->object->parent == orig->parent) {
 			if (html_object_get_direction (cursor->object) == HTML_DIRECTION_RTL)
-				cursor->offset --;
+				cursor->offset--;
 			else
-				cursor->offset ++;
+				cursor->offset++;
 		}
 
 		return rv;
@@ -1137,7 +1153,8 @@ move_right (HTMLCursor *cursor, HTMLEngine *e)
 }
 
 gboolean
-html_cursor_right (HTMLCursor *cursor, HTMLEngine *engine)
+html_cursor_right (HTMLCursor *cursor,
+                   HTMLEngine *engine)
 {
 	gboolean retval;
 
@@ -1158,7 +1175,8 @@ html_cursor_right (HTMLCursor *cursor, HTMLEngine *engine)
 }
 
 static gboolean
-right_in_flow (HTMLCursor *cursor, HTMLEngine *e)
+right_in_flow (HTMLCursor *cursor,
+               HTMLEngine *e)
 {
 	gboolean retval;
 
@@ -1184,7 +1202,8 @@ right_in_flow (HTMLCursor *cursor, HTMLEngine *e)
 }
 
 static gboolean
-html_cursor_right_edge_of_line (HTMLCursor *cursor, HTMLEngine *engine)
+html_cursor_right_edge_of_line (HTMLCursor *cursor,
+                                HTMLEngine *engine)
 {
 	HTMLCursor prev_cursor;
 	gint x, y, prev_y;
@@ -1205,7 +1224,7 @@ html_cursor_right_edge_of_line (HTMLCursor *cursor, HTMLEngine *engine)
 				     &x, &prev_y);
 
 	while (1) {
-		if (! right_in_flow (cursor, engine))
+		if (!right_in_flow (cursor, engine))
 			return TRUE;
 
 		html_object_get_cursor_base (cursor->object, engine->painter, cursor->offset,
@@ -1221,7 +1240,8 @@ html_cursor_right_edge_of_line (HTMLCursor *cursor, HTMLEngine *engine)
 }
 
 gboolean
-html_cursor_beginning_of_line (HTMLCursor *cursor, HTMLEngine *engine)
+html_cursor_beginning_of_line (HTMLCursor *cursor,
+                               HTMLEngine *engine)
 {
 	if (html_object_get_direction (cursor->object) == HTML_DIRECTION_RTL)
 		return html_cursor_right_edge_of_line (cursor, engine);
@@ -1230,7 +1250,8 @@ html_cursor_beginning_of_line (HTMLCursor *cursor, HTMLEngine *engine)
 }
 
 gboolean
-html_cursor_end_of_line (HTMLCursor *cursor, HTMLEngine *engine)
+html_cursor_end_of_line (HTMLCursor *cursor,
+                         HTMLEngine *engine)
 {
 	if (html_object_get_direction (cursor->object) == HTML_DIRECTION_RTL)
 		return html_cursor_left_edge_of_line (cursor, engine);
